@@ -5,7 +5,7 @@ import pandas as pd
 import numpy as np
 import numpy.testing as npt
 
-from inferelator_prior.motifs._motif import __MotifScanner as MotifScanner
+from inferelator_prior.motifs._motif import MotifScanner as MotifScanner
 from inferelator_prior.motifs import Motif, fimo, homer, SCAN_SCORE_COL
 
 artifact_path = os.path.join(os.path.abspath(os.path.expanduser(os.path.dirname(__file__))), "artifacts")
